pub struct KeyConnectorUserDecryptionOption {
pub key_connector_url: String,
}Expand description
SDK domain model for Key Connector user decryption option.
Fields
key_connector_url: StringURL of the Key Connector server to use for decryption.